==> kado-3.6.20.tgz: package/lang/spa.js <==
'use strict';
/**
 * Kado - Module system for Enterprise Grade applications.
 * Copyright © 2015-2019 NULLIVEX LLC. All rights reserved.
 * Kado <support@kado.org>
 *
 * This file is part of Kado.
 *
 * Kado is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Kado is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Kado.  If not, see <https://www.gnu.org/licenses/>.
 */

//Kado english language pack
module.exports = {
  '_pack_name': 'Spanish',
  '_pack_version': '1.0',
  '_pack_author': 'Nullivex',
  '_pack_system': 'Kado',
  '_pack_module': 'none',
  '_pack_code': 'spa',
  '_pack_sc': 'es',
  '_pack_flag': 'es',
  'admin_panel': 'Panel',
  'kado': 'Kado',
  'kado_description': 'Sistema de desarrollo para aplicaciones web..',
  'version': 'Versión',
  'welcome_to': 'Bienvenido a',
  'an_error_occurred': 'Se ha producido un error :(',
  'remove': 'Retirar',
  'login': 'Iniciar sesión',
  'sign_in': 'Registrarse',
  'toggle_nav': 'Alternar navegación',
  'home': 'Casa',
  'list': 'Lista',
  'create': 'Crear',
  'update': 'Actualizar',
  'download': 'Descargar',
  'edit': 'Editar',
  'staff_title': 'Personal',
  'action': 'Acción',
  'active': 'Activo',
  'created': 'Creado',
  'updated': 'Actualizada',
  'downloaded': 'Descargado',
  'saved': 'Salvado',
  'list_staff': 'Lista de personal',
  'create_staff': 'Crear personal',
  'settings': 'Configuraciones',
  'logout': 'Cerrar sesión',
  'toggle_sidebar': 'Toggle Sidebar',
  'navigation': 'Alternar barra lateral',
  'create_entry': 'Crear entrada',
  'from_the_press': 'De la prensa',
  'older': 'Mayor',
  'newer': 'Más nuevo',
  'title': 'Título',
  'save': 'Salvar',
  'uri': 'URI',
  'subscribe': 'Suscribir',
  'dashboard': 'Tablero',
  'permdenied': 'Permiso denegado',
  'invalid_login': 'Ingreso invalido',
  'no_staff_for_args': 'No se encontró personal para argumentos dados',
  'history': 'Historia',
  'search_results': 'Resultados de la búsqueda'
}

==> kado-3.7.10.tgz: package/lang/spa.js <==
'use strict';
/**
 * Kado - Web Application System
 * Copyright © 2015-2019 Bryan Tong, NULLIVEX LLC. All rights reserved.
 * Kado <support@kado.org>
 *
 * This file is part of Kado and bound to the MIT license distributed within.
 */

//Kado english language pack
module.exports = {
  '_pack_name': 'Spanish',
  '_pack_version': '1.0',
  '_pack_author': 'Nullivex',
  '_pack_system': 'Kado',
  '_pack_module': 'none',
  '_pack_code': 'spa',
  '_pack_sc': 'es',
  '_pack_flag': 'es',
  'admin_panel': 'Panel',
  'kado': 'Kado',
  'kado_description': 'Sistema de aplicación web.',
  'version': 'Versión',
  'welcome_to': 'Bienvenido a',
  'an_error_occurred': 'Se ha producido un error :(',
  'remove': 'Retirar',
  'login': 'Iniciar sesión',
  'sign_in': 'Registrarse',
  'toggle_nav': 'Alternar navegación',
  'home': 'Casa',
  'list': 'Lista',
  'create': 'Crear',
  'update': 'Actualizar',
  'download': 'Descargar',
  'edit': 'Editar',
  'staff_title': 'Personal',
  'action': 'Acción',
  'active': 'Activo',
  'created': 'Creado',
  'updated': 'Actualizada',
  'downloaded': 'Descargado',
  'saved': 'Salvado',
  'list_staff': 'Lista de personal',
  'create_staff': 'Crear personal',
  'settings': 'Configuraciones',
  'logout': 'Cerrar sesión',
  'toggle_sidebar': 'Toggle Sidebar',
  'navigation': 'Alternar barra lateral',
  'create_entry': 'Crear entrada',
  'from_the_press': 'De la prensa',
  'older': 'Mayor',
  'newer': 'Más nuevo',
  'title': 'Título',
  'save': 'Salvar',
  'uri': 'URI',
  'subscribe': 'Suscribir',
  'dashboard': 'Tablero',
  'permdenied': 'Permiso denegado',
  'invalid_login': 'Ingreso invalido',
  'no_staff_for_args': 'No se encontró personal para argumentos dados',
  'history': 'Historia',
  'search_results': 'Resultados de la búsqueda'
}
